@@ -3,7 +3,7 @@
 """
 BaseHTTPRequestHandler classes.
 
-Copyright (C) 2004, 2005 Paul Boddie <paul@boddie.org.uk>
+Copyright (C) 2004, 2005, 2006, 2007 Paul Boddie <paul@boddie.org.uk>
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public
@@ -51,8 +51,6 @@ class Transaction(WebStack.Generic.Transaction):
         self.content = StringIO()
         self.headers_out = {}
         self.cookies_out = SimpleCookie()
-        self.user = None
-        self.path_info = None
 
         # Define the incoming cookies.
 
@@ -105,6 +103,18 @@ class Transaction(WebStack.Generic.Transaction):
         self.trans.end_headers()
         self.trans.wfile.write(content)
 
+    def rollback(self):
+
+        """
+        A special method, partially synchronising the transaction with
+        framework-specific objects, but discarding previously emitted content
+        that is to be replaced by an error message.
+        """
+
+        self.content = StringIO()
+        self.headers_out = {}
+        self.cookies_out = SimpleCookie()
+
     # Server-related methods.
 
     def get_server_name(self):
@@ -272,6 +282,8 @@ class Transaction(WebStack.Generic.Transaction):
 
         # NOTE: Support at best ISO-8859-1 values.
 
+        encoding = encoding or self.default_charset
+
         fields = {}
         for name, values in parse_qs(self.get_query_string(), keep_blank_values=1).items():
             name = decode_value(name, encoding)
@@ -292,7 +304,8 @@ class Transaction(WebStack.Generic.Transaction):
         Returns a dictionary mapping field names to lists of values (even if a
         single value is associated with any given field name). Each value is
         either a Unicode object (representing a simple form field, for example)
-        or a plain string (representing a file upload form field, for example).
+        or a WebStack.Helpers.Request.FileContent object (representing a file
+        upload form field).
         """
 
         encoding = encoding or self.get_content_type().charset or self.default_charset
@@ -325,7 +338,8 @@ class Transaction(WebStack.Generic.Transaction):
         Returns a dictionary mapping field names to lists of values (even if a
         single value is associated with any given field name). Each value is
         either a Unicode object (representing a simple form field, for example)
-        or a plain string (representing a file upload form field, for example).
+        or a WebStack.Helpers.Request.FileContent object (representing a file
+        upload form field).
 
         Where a given field name is used in both the path and message body to
         specify values, the values from both sources will be combined into a
