@@ -3,7 +3,7 @@
 """
 Java Servlet classes.
 
-Copyright (C) 2004, 2005 Paul Boddie <paul@boddie.org.uk>
+Copyright (C) 2004, 2005, 2006 Paul Boddie <paul@boddie.org.uk>
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public
@@ -102,8 +102,6 @@ class Transaction(WebStack.Generic.Transaction):
         self.request = request
         self.response = response
         self.status = None
-        self.user = None
-        self.path_info = None
 
         # Remember the cookies received in the request.
         # NOTE: Discarding much of the information received.
@@ -326,7 +324,8 @@ class Transaction(WebStack.Generic.Transaction):
         Returns a dictionary mapping field names to lists of values (even if a
         single value is associated with any given field name). Each value is
         either a Unicode object (representing a simple form field, for example)
-        or a plain string (representing a file upload form field, for example).
+        or a WebStack.Helpers.Request.FileContent object (representing a file
+        upload form field).
         """
 
         # There may not be a reliable means of extracting only the fields
@@ -374,7 +373,8 @@ class Transaction(WebStack.Generic.Transaction):
         Returns a dictionary mapping field names to lists of values (even if a
         single value is associated with any given field name). Each value is
         either a Unicode object (representing a simple form field, for example)
-        or a plain string (representing a file upload form field, for example).
+        or a WebStack.Helpers.Request.FileContent object (representing a file
+        upload form field).
 
         Where a given field name is used in both the path and message body to
         specify values, the values from both sources will be combined into a
