@@ -3,7 +3,7 @@
 """
 mod_python classes.
 
-Copyright (C) 2004, 2005 Paul Boddie <paul@boddie.org.uk>
+Copyright (C) 2004, 2005, 2006, 2007 Paul Boddie <paul@boddie.org.uk>
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public
@@ -56,8 +56,6 @@ class Transaction(WebStack.Generic.Transaction):
         self.trans = trans
         self.response_code = apache.OK
         self.content_type = None
-        self.user = None
-        self.path_info = None
 
         # Support non-framework cookies.
 
@@ -154,7 +152,7 @@ class Transaction(WebStack.Generic.Transaction):
         charset employed.
         """
 
-        return self.parse_content_type(self.trans.content_type)
+        return self.parse_content_type(self.trans.headers_in.get("Content-Type"))
 
     def get_content_charsets(self):
 
@@ -185,6 +183,8 @@ class Transaction(WebStack.Generic.Transaction):
         character values.
         """
 
+        encoding = encoding or self.default_charset
+
         query_string = self.get_query_string()
         if query_string:
             return decode_value(self.trans.uri, encoding) + "?" + query_string
@@ -203,6 +203,8 @@ class Transaction(WebStack.Generic.Transaction):
         character values.
         """
 
+        encoding = encoding or self.default_charset
+
         return decode_value(self.trans.uri, encoding)
 
     def get_path_info(self, encoding=None):
@@ -218,6 +220,8 @@ class Transaction(WebStack.Generic.Transaction):
         character values.
         """
 
+        encoding = encoding or self.default_charset
+
         return decode_value(self.trans.path_info, encoding)
 
     def get_query_string(self):
@@ -243,6 +247,8 @@ class Transaction(WebStack.Generic.Transaction):
         single value is associated with any given field name).
         """
 
+        encoding = encoding or self.default_charset
+
         fields = {}
         for name, values in parse_qs(self.get_query_string(), 1).items(): # keep_blank_values=1
             name = decode_value(name, encoding)
@@ -263,7 +269,8 @@ class Transaction(WebStack.Generic.Transaction):
         Returns a dictionary mapping field names to lists of values (even if a
         single value is associated with any given field name). Each value is
         either a Unicode object (representing a simple form field, for example)
-        or a plain string (representing a file upload form field, for example).
+        or a WebStack.Helpers.Request.FileContent object (representing a file
+        upload form field).
 
         The mod_python.util.FieldStorage class may augment the fields from the
         body with fields found in the path.
@@ -308,7 +315,8 @@ class Transaction(WebStack.Generic.Transaction):
         Returns a dictionary mapping field names to lists of values (even if a
         single value is associated with any given field name). Each value is
         either a Unicode object (representing a simple form field, for example)
-        or a plain string (representing a file upload form field, for example).
+        or a WebStack.Helpers.Request.FileContent object (representing a file
+        upload form field).
 
         Where a given field name is used in both the path and message body to
         specify values, the values from both sources will be combined into a
