@@ -1,9 +1,8 @@
 #!/usr/bin/env python
 
-from WebStack.Adapters import JavaServlet
+from WebStack.Adapters.JavaServlet import deploy
 from Simple import SimpleResource
 from WebStack.Resources.LoginRedirect import LoginRedirectResource, LoginRedirectAuthenticator
-from javax.servlet.http import HttpServlet
 
 # NOTE: Not sure if the resource should be maintained in a resource pool.
 
@@ -16,13 +15,6 @@ resource = LoginRedirectResource(
     logout_parameter_name="logout"
     )
 
-class SimpleWithLoginApp(HttpServlet):
-    def __init__(self):
-        global resource
-        HttpServlet.__init__(self)
-        self.dispatcher = JavaServlet.Dispatcher(resource)
-
-    def service(self, request, response):
-        self.dispatcher.service(request, response)
+SimpleWithLoginApp = deploy(resource)
 
 # vim: tabstop=4 expandtab shiftwidth=4
