@@ -1,12 +1,11 @@
 #!/usr/bin/env python
 
-# NOTE: Path manipulation requires manual customisation.
+# NOTE: Path manipulation may require manual customisation.
 
-import sys
-sys.path.append("/home/paulb/Software/Python/WebStack")
-sys.path.append("/home/paulb/Software/Python/WebStack/examples/Common")
+import sys, os
+sys.path.append(os.path.abspath(os.path.join(__file__, "../../../Common")))
 
-from WebStack.Adapters import ModPython
+from WebStack.Adapters.ModPython import deploy
 from WebStack.Resources.Login import LoginResource, LoginAuthenticator
 
 # NOTE: Not sure if the resource should be maintained in a resource pool.
@@ -22,8 +21,6 @@ resource = LoginResource(
     use_redirect=0
 )
 
-def handler(req):
-    global resource
-    return ModPython.respond(req, resource, handle_errors=0)
+handler, _no_authentication = deploy(resource, handle_errors=1)
 
 # vim: tabstop=4 expandtab shiftwidth=4
