@@ -1,10 +1,11 @@
 #!/usr/bin/env python
 
-# NOTE: Path manipulation requires manual customisation.
+# Uncomment and adjust the paths below if WebStack is not installed somewhere
+# on the PYTHONPATH.
 
-import sys
-sys.path.append("/home/paulb/Software/Python/WebStack")
-sys.path.append("/home/paulb/Software/Python/WebStack/examples/Common")
+#import sys
+#sys.path.append("/home/paulb/Software/Python/WebStack")
+#sys.path.append("/home/paulb/Software/Python/WebStack/examples/Common")
 
 from WebStack.Adapters.WSGI import deploy
 from WebStack.Resources.LoginRedirect import LoginRedirectResource, LoginRedirectAuthenticator
