@@ -4,7 +4,7 @@
 Webware context for the Login application (post Webware 0.8.1).
 """
 
-from WebStack.Adapters.Webware import WebStackURLParser
+from WebStack.Adapters.Webware import deploy
 from WebStack.Resources.Login import LoginResource, LoginAuthenticator
 
 # NOTE: Initialising a shared resource.
@@ -19,6 +19,6 @@ resource = LoginResource(
     )
 )
 
-urlParser = WebStackURLParser(resource)
+urlParser = deploy(resource, handle_errors=1)
 
 # vim: tabstop=4 expandtab shiftwidth=4
