@@ -4,12 +4,12 @@
 Webware context for the Simple application (post Webware 0.8.1).
 """
 
-from WebStack.Adapters.Webware import WebStackURLParser
+from WebStack.Adapters.Webware import deploy
 from Simple import SimpleResource
 
 # NOTE: Initialising a shared resource.
 
 resource = SimpleResource()
-urlParser = WebStackURLParser(resource, handle_errors=0)
+urlParser = deploy(resource, handle_errors=1)
 
 # vim: tabstop=4 expandtab shiftwidth=4
