@@ -4,7 +4,7 @@
 Webware context for the Simple application (post Webware 0.8.1).
 """
 
-from WebStack.Adapters.Webware import WebStackURLParser
+from WebStack.Adapters.Webware import deploy
 from WebStack.Resources.LoginRedirect import LoginRedirectResource, LoginRedirectAuthenticator
 from Simple import SimpleResource
 
@@ -18,6 +18,6 @@ resource = LoginRedirectResource(
     anonymous_parameter_name="anonymous",
     logout_parameter_name="logout"
 )
-urlParser = WebStackURLParser(resource)
+urlParser = deploy(resource, handle_errors=1)
 
 # vim: tabstop=4 expandtab shiftwidth=4
