@@ -4,12 +4,12 @@
 Webware context for the VerySimple application (post Webware 0.8.1).
 """
 
-from WebStack.Adapters.Webware import WebStackURLParser
+from WebStack.Adapters.Webware import deploy
 from VerySimple import VerySimpleResource
 
 # NOTE: Initialising a shared resource.
 
 resource = VerySimpleResource()
-urlParser = WebStackURLParser(resource, handle_errors=0)
+urlParser = deploy(resource, handle_errors=1)
 
 # vim: tabstop=4 expandtab shiftwidth=4
